@@ -10,6 +10,7 @@ from idm_lp.commands import (
     delete_notify,
     disable_notifications,
     duty_signal,
+    get_database,
     info,
     nometa,
     members_manager,
@@ -36,6 +37,7 @@ commands_bp = (
     delete_notify.user,
     disable_notifications.user,
     duty_signal.user,
+    get_database.user,
     run_eval.user,
     ping.user,
     info.user,
