@@ -2,8 +2,7 @@ import json
 
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 
-
-__version__ = '1.13.1'
+__version__ = '1.13.6'
 __author__ = 'lordralinc'
 __description__ = (
     "LP модуль позволяет работать приемнику сигналов «IDM multi» работать в любых чатах. "
@@ -28,6 +27,10 @@ def GET_LP_INFO_LINK():
     return f"{BASE_DOMAIN}/api/dutys/get_lp_info/"
 
 
+def SAVE_LP_INFO_LINK():
+    return f"{BASE_DOMAIN}/api/dutys/save_lp_info/"
+
+
 GITHUB_LINK = "https://github.com/IDM-Team/idm_lp"
 VERSION_REST = "https://raw.githubusercontent.com/IDM-Team/idm_lp/master/rest/version.json"
 ALIASES_REST = "https://raw.githubusercontent.com/IDM-Team/idm_lp/master/rest/aliases.json"
@@ -47,5 +50,4 @@ except:
 
 APP_USER_AGENT = f"IDMLP({APP_ID};{APP_SECRET})"
 
-
 scheduler = AsyncIOScheduler()
